Release History
===============

1.1.1 (2023-03-06)
------------------

**Improvements**
- Update documentation 

**Bugfixes**

- Fixed typos
- Fixed readthedocs documentation of api


1.1.0 (2022-08-19)
------------------

**Improvements**

- Update and tidy up requirements
- Move cython and matplotlib to optional requirements
- Add nix python flake for development shell
- Add remimazolam with Schmith and Schuttler models
- Add etomidate with Lin and Kaneda models
- Update docs with new modules

**Bugfixes**

- Fixed pkpd cython module import


1.0.5 (2021-10-24)
------------------

**Improvements**

- Added Klamp ketamine model
- Documentation updates

**Bugfixes**

- Fixed ke0 example 
- Added missing self to Schnider model

1.0.4 (2021-05-13)
------------------

First working release




